@@ -1,7 +1,8 @@
 ;;; Directory Local Variables
 ;;; For more information see (info "(emacs) Directory Variables")
 
-((emacs-lisp-mode
-  (byte-compile-docstring-max-column . 100)
+((nil
+  (fill-column . 72)
+  (sentence-end-double-space . t)
   (show-trailing-whitespace . t)
   (indent-tabs-mode . nil)))
